Contributing
============

Contributions are welcome, and they are greatly appreciated! Every little bit helps, and credit will always be given.

You can contribute in many ways:

Types of Contributions
----------------------

### Report Bugs

Report bugs at https://github.com/czbiohub/cerebra/issues.

If you are reporting a bug, please include:

-   Your operating system name and version.
-   The python version you are using. 
-   Any other details about your local setup that might be helpful in troubleshooting.
-   Detailed steps to reproduce the bug.
-   Screenshots or code snippets, when applicable. 

### Fix Bugs

Look through the GitHub issues for bugs. Anything tagged with "bug" is open to whoever wants to implement it.

### Implement Features

Look through the GitHub issues for features/enhancement requests. Anything tagged with "enhancement" is open to whoever wants to implement it.

### Write Documentation

`cerebra` could always use more documentation, whether as
part of the official `cerebra` docs, in docstrings, or
even on the web in blog posts, articles, and such.

If there is a function/module that you think could use additional documentation, or is simply unclear to you, please let us know. 

### Submit Feedback

The best way to send feedback is to file an issue at https://github.com/czbiohub/cerebra/issues.

If you are proposing a feature:

-   Explain in detail how it would work.
-   Keep the scope as narrow as possible, to make it easier to implement.
-   Remember that this is a volunteer-driven project, and that contributions are welcome :)

Pull Request Guidelines
-----------------------

Before you submit a pull request, check that it meets these guidelines:

1.  The pull request should include tests, ideally with >60% code coverage. 
2.  Functionality should be encapsulated within a function(s) that includes a docstring. 
3.  The pull request should work for Python 3.6, 3.7 and potentially 3.8. Check
    https://travis-ci.org/github/czbiohub/cerebra/pull_requests and make sure that the tests pass
    for all supported Python versions.

Tips
----

To run a subset of tests:

    $ pytest test_you_want_to_run.py
